% This function constructs the natrual conjugage priors on (A,Sigr) and (B,Sigc)
%
% See:
% Chan, J.C.C. and Qi, Y. (2025). Large Bayesian Matrix Autoregressions, 
% Journal of Econometrics, forthcoming

function [A0,VA0,B0,VB0,nur,Sr,nuc,Sc,U_hat] = prior_MAR_NCP(p,kappaA,kappaB,Y0,Y)
[n,k,T] = size(Y);
A0 = zeros(n*p,n);
sig2hat = zeros(n,k);
U_hat = zeros(n,k,T);
B0 = kron(ones(p,1),speye(k));
% B0 = kron(ones(p,1),(k-1)/k*speye(k)+1/k*ones(k,k));

    % construct VA0 and VB0
for i=1:n
    for j=1:k
        tmpy = [squeeze(Y0(i,j,end-4+1:end)); squeeze(Y(i,j,:))];
        Z = [ones(T,1),tmpy(4:end-1),tmpy(3:end-2),tmpy(2:end-3),tmpy(1:end-4)];
        ZZ = Z'*Z + 1e-4*eye(5);
        tmpb = ZZ\(Z'*tmpy(5:end));
        u = tmpy(5:end)-Z*tmpb;
        sig2hat(i,j) = mean(u.^2);
        U_hat(i,j,:) = u;
    end
end
sig2r_mean = mean(sig2hat,2);
sig2c_mean = mean(sig2hat,1)';
VA0 = kappaA./(kron((1:p)'.^2,ones(n,1)).*repmat(sig2r_mean,p,1));
VB0 = kappaB./(kron((1:p)'.^2,ones(k,1)).*repmat(sig2c_mean,p,1));

Sr = diag(sig2r_mean); nur = n+2;
Sc = diag(sig2c_mean/sig2c_mean(1)); nuc = k+2;
end