% This function constructs the independent normal and inverse-Wishart priors
% on A and B
%
% See:
% Chan, J.C.C. and Qi, Y. (2025). Large Bayesian Matrix Autoregressions, 
% Journal of Econometrics, forthcoming

function [a0,Va,b0,Vb] = prior_MAR_indep(p,kappaA,kappaB,Y0,Y)
[n,k,T] = size(Y);
a0 = zeros(n^2*p,1);
b0 = reshape(kron(ones(p,1),speye(k)),k^2*p,1);
sig2hat = zeros(n,k);


    % construct Va and VbB0
for i=1:n
    for j=1:k
        tmpy = [squeeze(Y0(i,j,end-4+1:end)); squeeze(Y(i,j,:))];
        Z = [ones(T,1),tmpy(4:end-1),tmpy(3:end-2),tmpy(2:end-3),tmpy(1:end-4)];
        tmpb = (Z'*Z)\(Z'*tmpy(5:end));
        u = tmpy(5:end)-Z*tmpb;
        sig2hat(i,j) = mean(u.^2);        
    end
end
sig2r_mean = mean(sig2hat,2);
sig2c_mean = mean(sig2hat,1)';
VA0 = kappaA./(kron((1:p)'.^2,ones(n,1)).*repmat(sig2r_mean,p,1));
VB0 = kappaB./(kron((1:p)'.^2,ones(k,1)).*repmat(sig2c_mean,p,1));
Va = kron(sig2r_mean,VA0);
Vb = kron(sig2c_mean,VB0);
end