% This function constructs the natural conjugate prior/Minnesota prior
% without an intercept
%
% See:
% Chan, J.C.C. and Qi, Y. (2025). Large Bayesian Matrix Autoregressions, 
% Journal of Econometrics, forthcoming

function [A0,VA0,nu0,S0] = prior_NCP_no_intercept(p,kappa,Y0,Yt)
[Tt,n] = size(Yt);
k = n*p;
A0 = zeros(k,n);
VA0 = zeros(k,1);
sig2 = zeros(n,1);
    % construct VA0
tmpY = [Y0(end-4+1:end,:); Yt];
for i=1:n
    Z = [ones(Tt,1) tmpY(4:end-1,i) tmpY(3:end-2,i) tmpY(2:end-3,i)...
        tmpY(1:end-4,i)];
    tmpb = (Z'*Z)\(Z'*tmpY(5:end,i));
    sig2(i) = mean((tmpY(5:end,i)-Z*tmpb).^2);
end
for i=1:k
    l = ceil(i/n);
    idx = mod(i,n); % variable index
    if idx==0
        idx = n;
    end
    VA0(i) = kappa(1)/(l^2*sig2(idx));    
end
S0 = diag(sig2); nu0 = n+1;
VA0 = sparse(1:k,1:k,VA0);
end